@@ -1,4 +1,4 @@
-//Copyright 2016 Ryan Wick
+//Copyright 2017 Ryan Wick
 
 //This file is part of Bandage
 
@@ -142,7 +142,7 @@ Path Path::makeFromString(QString pathString, bool circular,
     }
 
     //Make sure there is at least one proposed node name listed.
-    QStringList nodeNameList = nodeListString.simplified().split(",", QString::SkipEmptyParts);
+    QStringList nodeNameList = nodeListString.simplified().split(",", Qt::SkipEmptyParts);
     if (nodeNameList.empty())
     {
         *pathStringFailure = "the text is not formatted correctly";
